@@ -31,6 +31,7 @@ from .models import Error
 from .models import IObtainable
 from .models import TokenResponse
 from .models import ServerMetadata
+from .nullcredential import NullCredential
 from .server import Server
 
 
@@ -54,8 +55,8 @@ class Client(httpx.Client):
 
     def __init__(
         self,
-        client_id: str,
-        client_secret: str,
+        client_id: str | None = None,
+        client_secret: str | None = None,
         issuer: str | None = None,
         client_auth: ClientAuthenticationMethod | None = None,
         authorization_endpoint: str | None = None,
@@ -69,15 +70,19 @@ class Client(httpx.Client):
             token_endpoint=token_endpoint,
             **kwargs
         )
-        super().__init__(
-            base_url=issuer or '',
+
+        # If the client_id is None, then this client is configured for
+        # a limited set of operations such as discovery, userinfo, etc.
+        if client_id is None:
+            credential = NullCredential()
+        else:
             credential=ClientCredential(
                 server=self.server,
                 client_id=client_id,
                 client_secret=client_secret,
                 using=client_auth
-            ),
-        )
+            )
+        super().__init__(base_url=issuer or '', credential=credential)
 
     async def authorize(
         self,
@@ -191,7 +196,10 @@ class Client(httpx.Client):
         originate from the configured authorization server.
         """
         assert self.metadata is not None
-        await self.credential.keychain
+        keychain = None
+        if self.credential.keychain:
+            await self.credential.keychain
+            keychain = self.credential.keychain
         if self.jwks is None:
             self.jwks = JSONWebKeySet()
             if self.metadata.jwks_uri is not None:
@@ -208,7 +216,7 @@ class Client(httpx.Client):
                 else:
                     self.jwks = JSONWebKeySet.parse_obj(await response.json())
         codec = PayloadCodec(
-            decrypter=self.credential.keychain,
+            decrypter=keychain,
             verifier=self.jwks
         )
         try:
@@ -224,4 +232,9 @@ class Client(httpx.Client):
         except (binascii.Error, Malformed, InvalidSignature, InvalidToken, TypeError):
             return False
 
-        return True
\ No newline at end of file
+        return True
+
+    async def __aenter__(self):
+        await super().__aenter__()
+        await self.discover()
+        return self
\ No newline at end of file
